@@ -30,6 +30,20 @@ def ensure_list(value):
     return value
 
 
+def ensure_unique_taxonomy(value):
+    """If there are several taxonomic classifications in the ssoCard, pick the most recent one."""
+    if isinstance(value, list):
+
+        value = {
+            "class": ", ".join(v["class"] for v in value),
+            "waverange": ", ".join(v["waverange"] for v in value),
+            "scheme": ", ".join(v["scheme"] for v in value),
+            "method": value[0]["method"],
+            "bibref": [v["bibref"] for v in value],
+        }
+    return value
+
+
 # ------
 # ssoCard as pydantic model
 
@@ -226,7 +240,7 @@ class Diameter(Value):
     method: List[Method] = []
     bibref: List[Bibref] = []
 
-    path_unit: str = "unit.physical.diameter.diameter.value"
+    path_unit: str = "unit.physical.diameter.diameter"
 
     _ensure_list: classmethod = pydantic.validator(
         "bibref", "method", allow_reuse=True, pre=True
@@ -237,7 +251,7 @@ class Mass(Value):
     bibref: List[Bibref] = [Bibref(**{})]
     method: List[Method] = [Method(**{})]
 
-    path_unit: str = "unit.physical.mass.mass.value"
+    path_unit: str = "unit.physical.mass.mass"
 
     _ensure_list: classmethod = pydantic.validator(
         "bibref", "method", allow_reuse=True, pre=True
@@ -335,6 +349,10 @@ class PhysicalParameters(Property):
         ensure_list
     )
 
+    _ensure_unique_taxonomy: classmethod = pydantic.validator(
+        "taxonomy", allow_reuse=True, pre=True
+    )(ensure_unique_taxonomy)
+
 
 # ------
 # Equation of state
@@ -471,16 +489,18 @@ class Rock(pydantic.BaseModel):
             if not ssocard:
                 ssocard = rocks.ssodnet.get_ssocard(id_)
 
-            for catalogue in datacloud:
-                ssocard = self.__add_datacloud_catalogue(id_, catalogue, ssocard)
+            if ssocard is None:
+                # Asteroid does not have an ssoCard. Instantiate minimal ssoCard for meaningful error output.
+                ssocard = {"name": id_provided}
+                print(f"Did not find ssoCard for asteroid '{id_provided}'.")
+
+            else:
+                for catalogue in datacloud:
+                    ssocard = self.__add_datacloud_catalogue(id_, catalogue, ssocard)
         else:
             # Something failed. Instantiate minimal ssoCard for meaningful error output.
             ssocard = {"name": id_provided}
 
-        if ssocard is None:
-            # Asteroid does not have an ssoCard. Instantiate minimal ssoCard for meaningful error output.
-            ssocard = {"name": id_provided}
-
         # Deserialize the asteroid data
         try:
             super().__init__(**ssocard)  # type: ignore
@@ -515,7 +535,10 @@ class Rock(pydantic.BaseModel):
         if name in self.__aliases["diamalbedo"]:
             return getattr(self, "diamalbedo")
 
-        raise AttributeError(f"'Rock' object has no attribute '{name}'")
+        raise AttributeError(
+            f"'Rock' object has no attribute '{name}'. Run "
+            f"'rocks properties' to get a list of accepted properties."
+        )
 
     def __repr__(self):
         return (
@@ -636,12 +659,21 @@ def rocks_(identifier, datacloud=[], progress=False):
     if isinstance(identifier, pd.Series):
         identifier = identifier.values
 
-    ids = [id_ for _, _, id_ in rocks.identify(identifier, return_id=True, progress=progress)]  # type: ignore
+    if len(identifier) == 1:
+        ids = [rocks.identify(identifier, return_id=True, progress=progress)[-1]]
+
+    else:
+        ids = [
+            id_
+            for _, _, id_ in rocks.identify(
+                identifier, return_id=True, progress=progress
+            )
+        ]
 
     rocks_ = [
         Rock(id_, skip_id_check=True, datacloud=datacloud)
         for id_ in tqdm(
-            ids, desc="Building rocks : ", total=len(ids), disable=~progress
+            ids, desc="Building rocks : ", total=len(ids), disable=not progress
         )
     ]
 
